package com.ruoyi.web.controller.qdtl;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.qdtl.domain.TlElectricDeviceLocation;
import com.ruoyi.qdtl.service.ITlElectricDeviceLocationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电动车定位设备轨迹Controller
 *
 * @author ruoyi
 * @date 2022-06-03
 */
@RestController
@RequestMapping("/qdtl/electricLocation")
public class TlElectricDeviceLocationController extends BaseController {
    @Autowired
    private ITlElectricDeviceLocationService tlElectricDeviceLocationService;

    /**
     * 查询电动车定位设备轨迹列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TlElectricDeviceLocation tlElectricDeviceLocation) {
        startPage();
        List<TlElectricDeviceLocation> list = tlElectricDeviceLocationService.selectTlElectricDeviceLocationList(tlElectricDeviceLocation);
        return getDataTable(list);
    }

    @GetMapping("/queryLocationRecord")
    public AjaxResult queryLocationRecord(@RequestParam String startDate,
                                          @RequestParam String endDate,
                                          @RequestParam(required = false) String areaName,
                                          @RequestParam(required = false) String imei) {
        startDate = startDate + " 00:00:00";
        endDate = endDate + " 23:59:59";
        return AjaxResult.success(tlElectricDeviceLocationService.queryLocationRecord(startDate, endDate, areaName, imei));
    }

    @PostMapping("/syncDeviceLocation")
    public AjaxResult syncDeviceLocation() {
        tlElectricDeviceLocationService.syncDeviceLocation();
        return AjaxResult.success();
    }

    @GetMapping("/getAllElectricDetail")
    public AjaxResult getAllElectricDetail() {
        return AjaxResult.success(tlElectricDeviceLocationService.getAllElectricDetail());
    }

    /**
     * 获取单个设备轨迹
     *
     * @return
     */
    @GetMapping("/getSingleElectricLocation")
    public AjaxResult getSingleElectricLocation(@RequestParam String startDate,
                                                @RequestParam String endDate,
                                                @RequestParam String imei) {
        startDate = startDate + " 00:00:00";
        endDate = endDate + " 23:59:59";
        return AjaxResult.success(tlElectricDeviceLocationService.getSingleElectricLocation(startDate, endDate, imei));
    }

    /**
     * 导出电动车定位设备轨迹列表
     */
    @Log(title = "电动车定位设备轨迹", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TlElectricDeviceLocation tlElectricDeviceLocation) {
        List<TlElectricDeviceLocation> list = tlElectricDeviceLocationService.selectTlElectricDeviceLocationList(tlElectricDeviceLocation);
        ExcelUtil<TlElectricDeviceLocation> util = new ExcelUtil<TlElectricDeviceLocation>(TlElectricDeviceLocation.class);
        util.exportExcel(response, list, "电动车定位设备轨迹数据");
    }

}
