package com.ruoyi.web.controller.qdtl;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.qdtl.domain.TlIncident;
import com.ruoyi.qdtl.service.ITlIncidentService;
import com.ruoyi.system.service.ISysRoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 巡检事件管理Controller
 *
 * @author ruoyi
 * @date 2022-08-09
 */
@RestController
@RequestMapping("/qdtl/incident")
public class TlIncidentController extends BaseController {
    @Autowired
    private ITlIncidentService tlIncidentService;
    @Autowired
    private ISysRoleService sysRoleService;

    /**
     * 查询巡检事件管理列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TlIncident tlIncident) {
        startPage();
        // 根据当前用户角色，如果是巡检员的话，则只查询自己的
        // 如果是巡检员管理员的话，查询接收人是自己的
        Set<String> roleSet = sysRoleService.selectRolePermissionByUserId(getUserId());
        if (roleSet.contains("xun")) {
            tlIncident.setCreateBy(getUsername());
        } else if (roleSet.contains("xun_manage")) {
            tlIncident.setAcceptUser(getUsername());
        }
        List<TlIncident> list = tlIncidentService.selectTlIncidentList(tlIncident);
        return getDataTable(list);
    }

    @GetMapping("/count")
    public AjaxResult count() {
        TlIncident tlIncident = new TlIncident();
        // 根据当前用户角色，如果是巡检员的话，则只查询自己的
        // 如果是巡检员管理员的话，查询接收人是自己的
        Set<String> roleSet = sysRoleService.selectRolePermissionByUserId(getUserId());
        if (roleSet.contains("xun")) {
            tlIncident.setCreateBy(getUsername());
        } else if (roleSet.contains("xun_manage")) {
            tlIncident.setAcceptUser(getUsername());
        }
        Map<String, Object> result = new HashMap<>();
        List<TlIncident> list = tlIncidentService.selectTlIncidentList(tlIncident);
        long unDeal = list.stream().filter(a -> StrUtil.equals(a.getStatus(), "1")).count();
        long deal = list.stream().filter(a -> StrUtil.equals(a.getStatus(), "2")).count();
        result.put("unDeal", unDeal);
        result.put("deal", deal);
        return AjaxResult.success(result);
    }

    /**
     * 导出巡检事件管理列表
     */
    @Log(title = "巡检事件管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TlIncident tlIncident) {
        List<TlIncident> list = tlIncidentService.selectTlIncidentList(tlIncident);
        ExcelUtil<TlIncident> util = new ExcelUtil<TlIncident>(TlIncident.class);
        util.exportExcel(response, list, "巡检事件管理数据");
    }

    /**
     * 获取巡检事件管理详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tlIncidentService.selectTlIncidentById(id));
    }

    /**
     * 新增巡检事件管理
     */
    @Log(title = "巡检事件管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TlIncident tlIncident) {
        tlIncident.setCreateBy(getUsername());
        tlIncident.setCreateByName(getLoginUser().getUser().getNickName());
        tlIncident.setStatus("1");
        return toAjax(tlIncidentService.insertTlIncident(tlIncident));
    }

    /**
     * 修改巡检事件管理
     */
    @Log(title = "巡检事件管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TlIncident tlIncident) {
        return toAjax(tlIncidentService.updateTlIncident(tlIncident));
    }

    @Log(title = "巡检事件管理-处理", businessType = BusinessType.UPDATE)
    @PutMapping("/deal")
    public AjaxResult deal(@RequestBody TlIncident tlIncident) {
        if (ObjectUtil.isNull(tlIncident.getId()) || StrUtil.isBlank(tlIncident.getStatus())) {
            return AjaxResult.error("缺少必要参数！");
        }
        TlIncident save = new TlIncident();
        save.setId(tlIncident.getId());
        save.setStatus(tlIncident.getStatus());
        save.setDealUser(getUsername());
        save.setDealUserName(getLoginUser().getUser().getNickName());
        save.setDealTime(new Date());
        return toAjax(tlIncidentService.updateTlIncident(save));
    }

    @Log(title = "巡检事件管理-处理备注和图片", businessType = BusinessType.UPDATE)
    @PutMapping("/dealRemark")
    public AjaxResult dealRemark(@RequestBody TlIncident tlIncident) {
        if (ObjectUtil.isNull(tlIncident.getId())) {
            return AjaxResult.error("缺少必要参数！");
        }
        TlIncident save = new TlIncident();
        save.setId(tlIncident.getId());
        save.setDealRemark(tlIncident.getDealRemark());
        save.setDealPics(tlIncident.getDealPics());
        save.setDealTime(new Date());
        return toAjax(tlIncidentService.updateTlIncident(save));
    }

    /**
     * 删除巡检事件管理
     */
    @Log(title = "巡检事件管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tlIncidentService.deleteTlIncidentByIds(ids));
    }


}
